@@ -12,7 +12,7 @@ use Perl::ToPerl6::Utils::PPI qw{ set_string };
 
 use base 'Perl::ToPerl6::Transformer';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 #-----------------------------------------------------------------------------
 
@@ -29,6 +29,65 @@ sub applies_to           {
            'PPI::Token::Quote::Double'
 }
 
+#-----------------------------------------------------------------------------
+
+# Tokenizer II: Electric Boogaloo.
+#
+# Since it'll eventually be needed...
+
+sub tokenize {
+    my ( $str ) = @_;
+    my @c = split //, $str;
+    my @token;
+
+    for ( my $i = 0; $i < @c; $i++ ) {
+        my ( $v, $la1 ) = @c[ $i, $i + 1 ];
+
+        if ( $v eq '\\' ) {
+            if ( $la1 eq 'c' ) {
+            }
+            elsif ( $la1 eq 'l' ) {
+            }
+            elsif ( $la1 eq 'u' ) {
+            }
+            elsif ( $la1 eq 'E' ) {
+            }
+            elsif ( $la1 eq 'F' ) {
+            }
+            elsif ( $la1 eq 'L' ) {
+            }
+            elsif ( $la1 eq 'Q' ) {
+            }
+            elsif ( $la1 eq 'U' ) {
+            }
+            else {
+            }
+        }
+        elsif ( $v eq '$' ) {
+        }
+        elsif ( $v eq '@' ) {
+        }
+        elsif ( $v eq '%' ) {
+        }
+        elsif ( $v eq '{' ) {
+        }
+        elsif ( $v eq '}' ) {
+        }
+        elsif ( $v eq '(' ) {
+        }
+        elsif ( $v eq ')' ) {
+        }
+        elsif ( $v eq '<' ) {
+        }
+        elsif ( $v eq '>' ) {
+        }
+        else {
+        }
+    }
+
+    return @token;
+}
+
 #-----------------------------------------------------------------------------
 #
 # Some more cases get folded away here (hee.)
@@ -60,14 +119,15 @@ sub casefold {
 }
 
 sub tokenize_variables {
-    my ($self, $string) = @_;
+    my ($self, $elem, $string) = @_;
     my $full_string = $string;
 
     my @tokens;
 my $iter = 100;
     while ( $string ) {
 unless ( --$iter  ) {
-    die "Congratulations, you've broken string interpolation. Please report this message, along with the test file you were using to the author: <<$full_string>>";
+    my $line_number = $elem->line_number;
+    die "Congratulations, you've broken string interpolation. Please report this message, along with the test file you were using to the author: <<$full_string>> on line $line_number\n";
 }
         my $residue;
 
@@ -76,6 +136,10 @@ unless ( --$iter  ) {
         if ( $string =~ s< ^ ( [\$\@] \{ [^}]+ \} ) ><>x ) {
             push @tokens, $1;
         }
+
+        # '\c' is a token on its own.
+        # '$\', '@\', '$ ', '@ ' is also its own token. Feels buggy though.
+        #
         elsif ( $string =~ s< ^ ( \\ c . ) ><>x or
                 $string =~ s< ^ ( [\$\@] (?: \\ | \s ) ) ><>x ) {
             if ( @tokens ) {
@@ -85,6 +149,10 @@ unless ( --$iter  ) {
                 push @tokens, $1;
             }
         }
+
+        # Anything that does *not* start with '$' or '@' is its own token,
+        # at least up until the next '$' or '@' encountered.
+        #
         elsif ( $string =~ s< ^ ( [^\$\@]+ ) ><>x ) {
             $residue .= $1;
 
@@ -103,11 +171,28 @@ unless ( --$iter  ) {
             }
             push @tokens, $self->casefold($residue);
         }
+
+        # Anything else starting with a '$' or '@' is fair game.
+        #
         elsif ( $string =~ m< ^ [\$\@] >x ) {
             my ( $var_name, $remainder, $prefix ) =
                  extract_variable( $string );
-            push @tokens, $var_name;
-            $string = $remainder;
+            if ( $var_name ) {
+                 push @tokens, $var_name;
+                 $string = $remainder;
+            }
+#
+# XXX I"m betting that extract_variable() doesn't quite catch $] etc.
+#
+            else {
+                $string =~ s< ^ ( [\$\@] [^\$\@]* ) ><>x;
+                if ( @tokens ) {
+                    $tokens[-1] .= $1;
+                }
+                else {
+                    push @tokens, $1;
+                }
+            }
         }
         else {
 warn "XXX failed\n";
@@ -217,7 +302,7 @@ warn "Interpolating perl code.";
     # hanging around in the string, because those would get messed up.
     #
 
-    my @tokens = $self->tokenize_variables($old_string);
+    my @tokens = $self->tokenize_variables($elem,$old_string);
 
     # Now on to rewriting \l, \u, \E, \F, \L, \Q, \U in Perl6.
     #
@@ -231,15 +316,32 @@ warn "Interpolating perl code.";
     # So, rather than having to retain case settings, we can simply stop the
     # lc(..) block after the first...
     #
-
     my $new_content;
     for ( my $i = 0; $i < @tokens; $i++ ) {
         my ( $v, $la1 ) = @tokens[$i,$i+1];
 
-        if ( index( $v, '$' ) != 0 and
-             index( $v, '@' ) != 0 ) {
-            $v =~ s< { ><\\{>gx;
-            $v =~ s< } ><\\}>gx;
+        if ( $v =~ m< ^ ( \$ | \@ ) >x ) {
+            if ( $v =~ s< ^ \$ \@ ><\\\$\@>x ) {
+            }
+            elsif ( $v =~ s< ^ ( \$ | \@ ) \{ ([^\}]+) \} ><{$1$2}>sx ) {
+            }
+            else {
+                $v =~ s< [-][\>] ><.>gx;
+                $v =~ s< \{ (\w+) (\s*) \} >< '{' .
+                                        $start_delimiter . $1 .
+                                        $end_delimiter . $2 .
+                                        '}'>segx;
+            }
+
+            $v =~ s< ^ ( [(<>)] ) ><\\$1>sgx;
+            $v =~ s< ( [^\\] ) ( [(<>)] ) ><$1\\$2>sgx;
+        }
+        else {
+            # < > is now a pointy block, { } is now a code block, ( ) is also
+            # used.
+            #
+            $v =~ s< ^ ( [{(<>)}] ) ><\\$1>sgx;
+            $v =~ s< ( [^\\] ) ( [{(<>)}] ) ><$1\\$2>sgx;
         }
         $new_content .= $v;
     }
