@@ -10,7 +10,7 @@ use Perl::ToPerl6::Utils::PPI qw{ is_ppi_token_word };
 
 use base 'Perl::ToPerl6::Transformer';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 #-----------------------------------------------------------------------------
 
@@ -46,7 +46,21 @@ sub applies_to           {
 sub transform {
     my ($self, $elem, $doc) = @_;
 
-    $elem->set_content('Any');
+    if ( $elem->snext_sibling and
+         $elem->snext_sibling->isa('PPI::Token::Symbol') and
+         $elem->snext_sibling->snext_sibling and
+         $elem->snext_sibling->snext_sibling->isa('PPI::Structure::Subscript') ) {
+        $elem->snext_sibling->snext_sibling->insert_after(
+            PPI::Token::Word->new(':delete')
+        );
+        $elem->next_sibling->delete if
+            $elem->next_sibling and
+            $elem->next_sibling->isa('PPI::Token::Whitespace');
+        $elem->remove;
+    }
+    else {
+        $elem->set_content('Any');
+    }
 
     return $self->transformation( $DESC, $EXPL, $elem );
 }
